@@ -6,7 +6,7 @@
 #
 # LLNL-CODE-797170
 # All rights reserved.
-# This file is part of Merlin, Version: 1.4.1.
+# This file is part of Merlin, Version: 1.5.0.
 #
 # For details, see https://github.com/LLNL/merlin.
 #
@@ -40,7 +40,10 @@ from io import StringIO
 import yaml
 from maestrowf.datastructures import YAMLSpecification
 
-from merlin.spec import defaults
+from merlin.spec import (
+    all_keys,
+    defaults,
+)
 
 
 def represent_none(self, _):
@@ -77,12 +80,14 @@ class MerlinSpec(YAMLSpecification):
         super(MerlinSpec, self).__init__()
 
     @classmethod
-    def load_specification(cls, filepath):
+    def load_specification(cls, filepath, suppress_warning=True):
         spec = super(MerlinSpec, cls).load_specification(filepath)
         with open(filepath, "r") as f:
             spec.merlin = MerlinSpec.load_merlin_block(f)
         spec.specroot = os.path.dirname(spec.path)
         spec.process_spec_defaults()
+        if not suppress_warning:
+            spec.warn_unrecognized_keys()
         return spec
 
     @classmethod
@@ -91,6 +96,7 @@ class MerlinSpec(YAMLSpecification):
         spec.merlin = MerlinSpec.load_merlin_block(StringIO(string))
         spec.specroot = None
         spec.process_spec_defaults()
+        # spec.warn_unrecognized_keys()
         return spec
 
     @staticmethod
@@ -144,6 +150,49 @@ class MerlinSpec(YAMLSpecification):
 
         recurse(object_to_update, default_dict)
 
+    def warn_unrecognized_keys(self):
+        # check description
+        MerlinSpec.check_section("description", self.description, all_keys.DESCRIPTION)
+
+        # check batch
+        MerlinSpec.check_section("batch", self.batch, all_keys.BATCH)
+
+        # check env
+        MerlinSpec.check_section("env", self.environment, all_keys.ENV)
+
+        # check parameters
+        for param, contents in self.globals.items():
+            MerlinSpec.check_section("global.parameters", contents, all_keys.PARAMETER)
+
+        # check steps
+        for step in self.study:
+            MerlinSpec.check_section(step["name"], step, all_keys.STUDY_STEP)
+            MerlinSpec.check_section(
+                step["name"] + ".run", step["run"], all_keys.STUDY_STEP_RUN
+            )
+
+        # check merlin
+        MerlinSpec.check_section("merlin", self.merlin, all_keys.MERLIN)
+        MerlinSpec.check_section(
+            "merlin.resources", self.merlin["resources"], all_keys.MERLIN_RESOURCES
+        )
+        for worker, contents in self.merlin["resources"]["workers"].items():
+            MerlinSpec.check_section(
+                "merlin.resources.workers " + worker, contents, all_keys.WORKER
+            )
+        if self.merlin["samples"]:
+            MerlinSpec.check_section(
+                "merlin.samples", self.merlin["samples"], all_keys.SAMPLES
+            )
+
+    @staticmethod
+    def check_section(section_name, section, all_keys):
+        diff = set(section.keys()).difference(all_keys)
+        for extra in diff:
+            LOG.warn(
+                f"Unrecognized key '{extra}' found in spec section '{section_name}'."
+            )
+
     def dump(self):
         """
         Dump this MerlinSpec to a yaml string.
